using MatrixDemo.Data;
using Microsoft.EntityFrameworkCore;
using System.ComponentModel;

namespace MatrixDemo
{
    public partial class Form1 : Form
    {
        private ApplicationDbContext? _context;

        public Form1()
        {
            InitializeComponent();
        }

        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);

            _context = new ApplicationDbContext();
            _context.Database.EnsureCreated();

            _context.Employees.Load();
            _context.Tools.Load();

            CreateMatrix();
        }

        protected override void OnClosing(CancelEventArgs e)
        {
            base.OnClosing(e);

            _context?.Dispose();
            _context = null;
        }

        private void CreateMatrix()
        {
            var employess = _context!.Employees.Include(e => e.TrainingProgresses).ToList();
            var tools = _context!.Tools.ToList();

            dataGridViewMatrix.Columns.Add(new DataGridViewTextBoxColumn() { HeaderText = "Name" });

            foreach (var tool in tools)
            {
                dataGridViewMatrix.Columns.Add(new DataGridViewCheckBoxColumn() { HeaderText = tool.Name });
            }

            foreach (var employee in employess)
            {
                DataGridViewRow row = new();
                row.Cells.Add(new DataGridViewTextBoxCell() { Value = $"{employee.FirstName} {employee.LastName}" });
                if ((employee.TrainingProgresses is not null) && employee.TrainingProgresses.Any())
                {
                    for (int i = 1; i < dataGridViewMatrix.Columns.Count; ++i)
                    {
                        var columnHeaderText = dataGridViewMatrix.Columns[i].HeaderText;

                        DataGridViewCheckBoxCell cell = new() { Value = employee.TrainingProgresses.Any(p => (p.Tool.Name == columnHeaderText) && p.Finished) };
                        row.Cells.Add(cell);
                    }
                }
                dataGridViewMatrix.Rows.Add(row);
            }
        }
    }
}